pub struct ListEntitlementsResponse {
pub entitlements: Option<Vec<Entitlement>>,
pub next_page_token: Option<String>,
}Expand description
Response message for PartnerProcurementService.ListEntitlements.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- entitlements list providers (response)
Fields
entitlements: Option<Vec<Entitlement>>The list of entitlements in this response.
next_page_token: Option<String>The token for fetching the next page.